Learn R Programming

trekcolors (version 0.2.0)

trek_pal: Star Trek color palettes

Description

Return a predefined Star Trek color palette from the trekpals dataset.

Usage

trek_pal(palette, reverse = FALSE)

view_trek_pals(palette)

Value

character vector of hex colors or palette names

Arguments

palette

character, name of predefined palette. If missing, return all available palette names.

reverse

logical, reverse color order.

Details

Many of the palettes are qualitative, and not necessarily evenly spaced in terms of hue, saturation or brightness. This is because many palettes come from logos, symbols, insignia and other simple representations. However, several palettes have specifically been constructed as sequential or divergent if it made sense to do so based on the dominant colors present. Additional special functions exist for the subset of LCARS palettes.

See Also

lcars_pals(), scale_lcars()

Examples

Run this code
trek_pal("lcars_2357")
# leave palette blank to list available names:
trek_pal()

# to view all palettes
view_trek_pals()

Run the code above in your browser using DataLab