lcars_pal() returns a predefined, qualitative LCARS color palette.
lcars_color_pal() returns a palette generator based on specific colors.
lcars_pals() is a function that takes no arguments and returns a list of
all predefined LCARS palettes.
Predefined palettes options for palette are "2357", "2369", "2375",
"2379", "alt", "first_contact", "nemesis", "nx01", "23c", "29c",
"red_alert" and "cardassian".
Custom palettes can also be constructed by passing a vector of colors to
palette in lcars_color_pal(). This is useful for sequential and divergent
palettes. This is essentially a wrapper around colorRampPalette() that
understands LCARS color names. It accepts any color, allowing you to still
use a color like "white" or "#FFFFFF" as the midpoint in a divergent
palette for example. A special case is when you provide only a single color,
e.g., lcars_color_pal("husk"); this is equivalent to
lcars_color_pal(c("white", "husk")).